using System;
using System.ComponentModel;
using System.Windows.Forms;

namespace WindowsApplication
{
    public partial class MainForm : Form
    {
        #region OpacityChanged event

        public class OpacityChangedEventArgs : EventArgs
        {
            private Double _value;

            public Double Value
            {
                get { return _value; }
                set { _value = value; }
            }

            public OpacityChangedEventArgs(Double value)
            {
                _value = value;
            }
        }

        public delegate void OpacityChangedEventHandler(Object sender, OpacityChangedEventArgs e);
        public event OpacityChangedEventHandler OpacityChanged;

        #endregion OpacityChanged event

        #region BindingSource and BindingList

        private BindingSource _bindingSource;
        private BindingList<String> _bindingList;

        #endregion BindingSource and BindingList

        #region Constructor

        public MainForm()
        {
            InitializeComponent();

            _bindingSource = new BindingSource();
            _bindingSource.Add("One");
            _bindingSource.Add("Two");
            _bindingSource.Add("Three");

            _bindingList = new BindingList<String>();
            _bindingList.Add("One");
            _bindingList.Add("Two");
            _bindingList.Add("Three");
        }

        #endregion Constructor

        #region Event handlers

        private void trackBarOpacity_ValueChanged(object sender, EventArgs e)
        {
            Opacity = (double)trackBarOpacity.Value / 100;
            if (OpacityChanged != null)
                OpacityChanged(this, new OpacityChangedEventArgs(Opacity));
        }

        private void btnCollect_Click(object sender, EventArgs e)
        {
            GC.Collect();
            GC.WaitForPendingFinalizers();
            GC.Collect();
        }

        private void btnEvent_Click(object sender, EventArgs e)
        {
            new EventForm(this).Show();
        }

        private void btnStaticEvent_Click(object sender, EventArgs e)
        {
            new StaticEventForm().Show();
        }

        private void btnContextMenuStripNotOK_Click(object sender, EventArgs e)
        {
            new ContextMenuStripNotOKForm().Show();
        }

        private void btnContextMenuOK1_Click(object sender, EventArgs e)
        {
            new ContextMenuStripOKForm().Show();
        }

        private void btnBindingSource_Click(object sender, EventArgs e)
        {
            new BindingSourceForm(_bindingSource).Show();
        }

        private void btnBindingList_Click(object sender, EventArgs e)
        {
            new BindingListForm(_bindingList).Show();
        }

        #endregion Event handlers
    }
}